import { d as data } from './generated-shared.js';

var main1 = data.map(d => d + 1);

export { main1 as default };
